Transfonter demo

# Myriad Pro Semibold Italic

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: 600;
        font-style: italic;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Black

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: 900;
        font-style: normal;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Semibold

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: 600;
        font-style: normal;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Black Italic

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: 900;
        font-style: italic;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Regular

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: normal;
        font-style: normal;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Bold

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: bold;
        font-style: normal;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Bold Italic

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: bold;
        font-style: italic;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Light Italic

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: 300;
        font-style: italic;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Italic

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: normal;
        font-style: italic;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

# Myriad Pro Light

    .your-style {
        font-family: 'Myriad Pro';
        font-weight: 300;
        font-style: normal;
    }

абвгдеёжзийклмнопрстуфхцчшщъыьэюя
АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ
abcdefghijklmnopqrstuvwxyz
ABCDEFGHIJKLMNOPQRSTUVWXYZ
0123456789.:,;()*!?'@#<>$%&^+-=~

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.

Съешь же ещё этих мягких французских булок, да выпей чаю.